pub struct DmaBufEncoder {
receiver: Option<Receiver<RawVideoFrame>>,
}Expand description
“Encoder” which provides the raw DMA-Buf pointers directly.
Allows for using the image directly on the GPU, which makes it far more performant when, for example, trying to display it to a user.
The implementations of crate::NvencEncoder and crate::VaapiEncoder show how a RawVideoFrame can be used.
Fields
receiver: Option<Receiver<RawVideoFrame>>Trait Implementations
Sourceimpl Default for DmaBufEncoder
impl Default for DmaBufEncoder
Sourcefn default() -> DmaBufEncoder
fn default() -> DmaBufEncoder
Returns the “default value” for a type. Read more
Sourceimpl PipewireSPA for DmaBufEncoder
impl PipewireSPA for DmaBufEncoder
fn get_spa_definition() -> Result<Object>
Sourceimpl StartVideoEncoder for DmaBufEncoder
impl StartVideoEncoder for DmaBufEncoder
fn start_processing( capture: &mut Capture<Self>, input: Receiver<RawVideoFrame>, ) -> Result<()>